import { Component } from 'react';
import { Link } from '../components/SingleRouter/SingleRouter';
import Spinner from '../components/Spinner/Spinner';
import { alert } from '../helper/alert';
import { apis } from '../helper/apis';
import { get } from '../helper/axios';
import { images } from '../resources.json';
import './index.css';

export class AppContainer extends Component {
  constructor(props) {
    super(props);
    this.state = {
      essentialMessages: [],
      essentialImages: [],
      fetchingEssential: false,
    };
  }

  componentDidMount() {
    if (this.state.fetchingEssential) return;
    this.setState({ fetchingEssential: true });
    get(apis.listEssence).then(({ data, status, networkStatus }) => {
      this.setState({ fetchingEssential: false });
      if (networkStatus !== 200) return;
      if (!status) return alert('获取精选列表失败：' + data + '，请刷新重试');
      let messages = [], images = [];
      data.forEach(post => {
        if (post.content) messages.push(post.content);
        if (post.image) images.push(post.image);
      });
      this.setState({ essentialMessages: messages, essentialImages: images });
    });
  }

  render() {
    return (
      <div className="index-container">
        <div className="poster">
          <img src={images.poster} className="img-poster" alt="海报" />
          <Link to="/upload" className="btn btn-light btn-straight btn-partIn">点击参加</Link>
        </div>
        <div className="content split-lg">
          <div className="card">
            <div className="card-header">
              精选留言
            </div>
            <div className="card-body">
              {
                this.state.fetchingEssential
                ? (
                  <div className="col-center"><Spinner isGray /></div>
                )
                : (
                  this.state.essentialMessages.length === 0
                  ? (
                    <div className="col-center">暂时没有精选留言</div>
                  )
                  : (
                    <ul className="message-list">
                      {
                        this.state.essentialMessages.map((msg, i) => (
                          <li dangerouslySetInnerHTML={{ __html: msg }} key={i}></li>
                        ))
                      }
                    </ul>
                  )
                )
              }
            </div>
          </div>
          <div className="card">
            <div className="card-header">
              精选图片
            </div>
            <div className="card-body">
              {
                this.state.fetchingEssential
                ? (
                  <div className="col-center"><Spinner isGray /></div>
                )
                : (
                  this.state.essentialImages.length === 0
                  ? (
                    <div className="col-center">暂时没有精选图片</div>
                  )
                  : (
                    <div className="img-list">
                      {
                        this.state.essentialImages.map((src, i) => (
                          <img src={src} key={i} alt="精选图片" />
                        ))
                      }
                    </div>
                  )
                )
              }
            </div>
          </div>
        </div>
      </div>
    );
  }
}